@@ -30,6 +30,7 @@ h.load_file("stdrun.hoc")
 
 from visio import Visio
 import manager
+import res # icons
 
 class Controls():
     """Main class Neuronvisio"""
@@ -83,20 +84,59 @@ class Controls():
                                          QtCore.SIGNAL("valueChanged(int)"),
                                          self.on_timeline_value_changed)
         
+        self.ui.actionLoad.connect(self.ui.actionLoad, 
+                                   QtCore.SIGNAL("triggered()"),
+                                   self.load_db)
+        self.ui.actionSave.connect(self.ui.actionSave,
+                                   QtCore.SIGNAL("triggered()"),
+                                   self.save_db)
+        self.ui.actionSave_As.connect(self.ui.actionSave_As,
+                                      QtCore.SIGNAL("triggered()"),
+                                      self.save_as_db)
+        
         ### Connection with the console
-        spinBoxDic = {'dt' : self.ui.dtSpinBox, 'tstop' : self.ui.tstopSpinBox,
-                      'v_init' : self.ui.vSpinBox}
-        self.timeLoop = Timeloop(spinBoxDic)
+        widgetDic = {'dt' : self.ui.dtSpinBox, 'tstop' : self.ui.tstopSpinBox,
+                      'v_init' : self.ui.vSpinBox, 'time_label' : self.ui.time_label}
+        self.timeLoop = Timeloop(widgetDic)
         self.timeLoop.start()
         
         
         ### Manager class 
         self.manager = manager.Manager()
-                            
+        self.path_to_sql = None                    
         self.ui.show()
         
         # Start the main event loop.
         app.exec_()
+    
+    def load_db(self):
+        filename = QtGui.QFileDialog.getOpenFileName()
+        self.path_to_sql = str(filename)
+        self.manager.load_db(self.path_to_sql)
+        self.update_tree_view()
+        msg = "Loaded db: %s" % self.path_to_sql
+        self.ui.statusbar.showMessage(msg, 3500)
+        
+        
+        
+    def save_db(self):
+        if not self.path_to_sql:
+            filename = QtGui.QFileDialog.getSaveFileName()
+            self.path_to_sql = str(filename) # It will go with python 3
+        self.manager.store_in_db(self.path_to_sql)
+        msg = "Saved Loaded db: %s" % self.path_to_sql
+        self.ui.statusbar.showMessage(msg, 3500)
+        
+    def save_as_db(self):
+
+        filename = QtGui.QFileDialog.getSaveFileName()
+        self.path_to_sql = str(filename)
+        self.manager.store_in_db(self.path_to_sql)
+        msg = "Saved Loaded db: %s" % self.path_to_sql
+        self.ui.statusbar.showMessage(msg, 3500)
+            
+        
+
         
     def launch_visio(self):
         if not hasattr(self, 'visio'):
@@ -120,9 +160,9 @@ class Controls():
         
         if len(self.manager.vecRefs) == 0:
             print "No vector Created. Create at least one vector to run the simulation"
+            return False
         else:
             v_init = self.ui.vSpinBox.value()
-            
             # Set the v_init
             h.v_init = v_init
             h.finitialize(v_init)
@@ -130,19 +170,21 @@ class Controls():
         
             # Reset the time in the GUI
             self.ui.time_label.setNum(h.t)
+            return True
+            
     
     def run(self):
         """Run the simulator till tstop"""
         
         #Initializing
-        self.init()
-        # Run
-        while h.t < h.tstop:
-            h.fadvance()
-            
-            self.ui.time_label.setText("<b>" + str(h.t) + "</b>")
-        # Enabling the animation
-        self.ui.animation_btn.setEnabled(True)
+        if self.init():
+            # Run
+            while h.t < h.tstop:
+                h.fadvance()
+                
+                self.ui.time_label.setText("<b>" + str(h.t) + "</b>")
+            # Enabling the animation
+            self.ui.animation_btn.setEnabled(True)
                     
     def tstop_changed(self):
         
@@ -163,9 +205,8 @@ class Controls():
         vecs_to_plot = {}
         var = ""
         for item in items:
-            if item.parent() is None:
-                print "Can't plot the section, skipping."
-            else:
+            if item.parent() is not None:
+                
                 sectionName = item.parent().text(0) #Column used
                 var = item.text(0)
                 
@@ -191,7 +232,12 @@ class Controls():
         
         var = self.ui.var.text()
         if var.isEmpty():
-            print "No var specified."
+
+            msgBox = QtGui.QMessageBox()
+            msgBox.setText("No var specified.")
+            msgBox.setIcon(QtGui.QMessageBox.Warning)
+            msgBox.exec_()
+ 
         else:
             if self.ui.all_sections.isChecked():
                 allCreated = self.manager.add_all_vecRef(str(var))
@@ -200,11 +246,15 @@ class Controls():
                     sec = self.visio.cyl2sec[self.visio.selected_cyl]
                     self.manager.add_vecRef(str(var), sec)
                 else:
-                    print ("Error: No vector has been created.")
-                    print ("Reason: No section has been selected.")
-        self._update_tree_view()
+                    msgBox = QtGui.QMessageBox()
+                    msgBox.setText("<b>No vector has been created.</b>")
+                    msg = "You need to select the section where you want to create the vector"
+                    msgBox.setInformativeText(msg)
+                    msgBox.setIcon(QtGui.QMessageBox.Warning)
+                    msgBox.exec_()
+        self.update_tree_view()
         
-    def _update_tree_view(self):
+    def update_tree_view(self):
         # Fill the treeview wit all the vectors created
         #Clear all the row
         self.ui.treeWidget.clear()
@@ -300,9 +350,9 @@ class Controls():
         
 class Timeloop(QtCore.QThread):
     """Daemon thread to connect the console with the gui"""
-    def __init__(self, spinBoxDict, parent = None):
+    def __init__(self, widgetDic, parent = None):
         QtCore.QThread.__init__(self, parent)
-        self.spinBoxDict = spinBoxDict
+        self.widgetDic = widgetDic
         
         
     def run(self):
@@ -310,11 +360,15 @@ class Timeloop(QtCore.QThread):
         while True:
             self.sleep(1) #check every sec
             
-            if h.dt != self.spinBoxDict['dt'].value():
-                self.spinBoxDict['dt'].setValue(h.dt)
-            if h.tstop != self.spinBoxDict['tstop'].value():
-                self.spinBoxDict['tstop'].setValue(h.tstop)
-            if h.v_init != self.spinBoxDict['v_init'].value():
-                self.spinBoxDict['v_init'].setValue(h.v_init)
+            if h.dt != self.widgetDic['dt'].value():
+                self.widgetDic['dt'].setValue(h.dt)
+            if h.tstop != self.widgetDic['tstop'].value():
+                self.widgetDic['tstop'].setValue(h.tstop)
+            if h.v_init != self.widgetDic['v_init'].value():
+                self.widgetDic['v_init'].setValue(h.v_init)
+#            if h.t != float (self.widgetDic['time_label'].text()):
+#                self.widgetDic['time_label'].setText(str(h.t))
+            
+                
             
             
\ No newline at end of file
